==> SAGElyzer_1.3.0.tar.gz: SAGElyzer/man/SAGEMapper.Rd <==
\name{SAGEMapper}
\alias{SAGEMapper}
\alias{doTag2UG}
\alias{doUG2Tag}
\alias{env2File}
\alias{getMapFileName}
\title{Annotating SAGE tags using data from public databases}
\description{
  Functions that provide data annotation using public databases and
  package AnnBuilder}.
}
\usage{
SAGEMapper(tag2UG = TRUE, tagUrl =
"ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel_Hs.zip",
organism = "Hs", fromWeb = TRUE)
doTag2UG(fileName)
doUG2Tag(fileName, sep = "\t", header = FALSE)
getMapFileName()
}

\arguments{
  \item{tag2UG}{A boolean set to be TRUE if the mapping will be between
    SAGE tags and UniGene ids or FALSE is the mapping will be between
    UniGene ids and SAGE tags}
  \item{tagUrl}{A character string for the url where mapping information
    can be downloaded}
  \item{fileName}{A character string for the name of the file where the
    mapping will be stored}
  \item{sep}{\code{sep} a character string for the separator used in the
    source file}
  \item{header}{\code{header} a boolean indicating whether the source
    file has a header line}
  \item{organism}{\code{organism} a character string for the organism of
    concern (e. g. Hs for human)}
  \item{fromWeb}{\code{fromWeb} a boolean indicating whether the source
    data should be downloaded from the web or read from a directory
    locally} 
}
\details{
  \code{\link{SAGEMapper}} reads mapping data from NCBI
  (\url{ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel_Hs.zip}) and produces a text file containing the mappings between SAGE tags and UniGene ids or UniGene ids and SAGE tags. The default url was valid for human genes at the time of development but needs to be updated when needed.

  \code{\link{doTag2UG}}, \code{\link{doUG2Tag}}, and
  \code{\link{env2File}} are called by \code{\link{SAGEMapper}} to
  perfome the required functions
}
\value{
  \item{doTag2UG}{Returns an R environment object containing mappings
    between SAGE tags and UniGene ids}
  \item{doUG2Tag}{Returns an R environment object containing mappings
    between UniGene ids SAGE tags}
}
\references{The help files for package AnnBuilder provides explations on
how to annotate data using AnnBuilder} 
\author{J. Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide bioinformatics functionalities through R}

\seealso{\code{\link{SAGELyzer}}}

\examples{
# The following code takes a while to run and is thus inactivated
\dontrun{SAGEMapper("theMap", "", TRUE,
"ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel_Hs.zip")}
}
\keyword{manip}

==> SAGElyzer_1.10.0.tar.gz: SAGElyzer/man/SAGEMapper.Rd <==
\name{SAGEMapper}
\alias{SAGEMapper}
\alias{doTag2UG}
\alias{doUG2Tag}
\alias{env2File}
\alias{getMapFileName}
\title{Annotating SAGE tags using data from public databases}
\description{
  Functions that provide data annotation using public databases and
  package AnnBuilder}
}
\usage{
SAGEMapper(tag2UG = TRUE, tagUrl =
                 "ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel.zip",
                 organism = "Hs", fromWeb = TRUE)
doTag2UG(fileName)
doUG2Tag(fileName, sep = "\t", header = FALSE)
getMapFileName()
}

\arguments{
  \item{tag2UG}{A boolean set to be TRUE if the mapping will be between
    SAGE tags and UniGene ids or FALSE is the mapping will be between
    UniGene ids and SAGE tags}
  \item{tagUrl}{A character string for the url where mapping information
    can be downloaded}
  \item{fileName}{A character string for the name of the file where the
    mapping will be stored}
  \item{sep}{\code{sep} a character string for the separator used in the
    source file}
  \item{header}{\code{header} a boolean indicating whether the source
    file has a header line}
  \item{organism}{\code{organism} a character string for the organism of
    concern (e. g. Hs for human)}
  \item{fromWeb}{\code{fromWeb} a boolean indicating whether the source
    data should be downloaded from the web or read from a directory
    locally} 
}
\details{
  \code{\link{SAGEMapper}} reads mapping data from NCBI
  (\url{ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel_Hs.zip}) and produces a text file containing the mappings between SAGE tags and UniGene ids or UniGene ids and SAGE tags. The default url was valid for human genes at the time of development but needs to be updated when needed.

  \code{\link{doTag2UG}}, \code{\link{doUG2Tag}}, and
  \code{\link{env2File}} are called by \code{\link{SAGEMapper}} to
  perfome the required functions
}
\value{
  \item{doTag2UG}{Returns an R environment object containing mappings
    between SAGE tags and UniGene ids}
  \item{doUG2Tag}{Returns an R environment object containing mappings
    between UniGene ids SAGE tags}
}
\references{The help files for package AnnBuilder provides explations on
how to annotate data using AnnBuilder} 
\author{J. Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide bioinformatics functionalities through R}

\seealso{\code{\link{SAGELyzer}}}

\examples{
# The following code takes a while to run and is thus inactivated
\dontrun{SAGEMapper("theMap", "", TRUE,
"ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel_Hs.zip")}
}
\keyword{manip}
